==> flexible-process-springboot-1.3.0.Final-sources.jar: org/kie/kogito/handlers/CommentService_addSupportComment_19_Handler.java <==
package org.kie.kogito.handlers;

import org.kie.kogito.process.workitem.WorkItemExecutionError;

@org.springframework.stereotype.Component()
public class CommentService_addSupportComment_19_Handler implements org.kie.kogito.internal.process.runtime.KogitoWorkItemHandler {

    org.kie.flexible.kogito.example.service.CommentService service;

    public CommentService_addSupportComment_19_Handler() {
        this(new org.kie.flexible.kogito.example.service.CommentService());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    @org.springframework.context.annotation.Lazy()
    public CommentService_addSupportComment_19_Handler(org.kie.flexible.kogito.example.service.CommentService service) {
        this.service = service;
    }

    public void executeWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
        java.lang.Object result;
        result = service.addSupportComment((org.kie.flexible.kogito.example.model.SupportCase) workItem.getParameter("supportCase"), (String) workItem.getParameter("comment"), (String) workItem.getParameter("author"));
        workItemManager.completeWorkItem(workItem.getStringId(), java.util.Collections.singletonMap("supportCase", result));
    }

    public void abortWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
    }

    public String getName() {
        return "org.kie.flexible.kogito.example.service.CommentService_addSupportComment_19_Handler";
    }
}

==> flexible-process-springboot-1.4.0.Final-sources.jar: org/kie/kogito/handlers/CommentService_addSupportComment_19_Handler.java <==
package org.kie.kogito.handlers;

import org.kie.kogito.process.workitem.WorkItemExecutionException;

@org.springframework.stereotype.Component()
public class CommentService_addSupportComment_19_Handler implements org.kie.kogito.internal.process.runtime.KogitoWorkItemHandler {

    org.kie.flexible.kogito.example.service.CommentService service;

    public CommentService_addSupportComment_19_Handler() {
        this(new org.kie.flexible.kogito.example.service.CommentService());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    @org.springframework.context.annotation.Lazy()
    public CommentService_addSupportComment_19_Handler(org.kie.flexible.kogito.example.service.CommentService service) {
        this.service = service;
    }

    public void executeWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
        java.lang.Object result;
        result = service.addSupportComment((org.kie.flexible.kogito.example.model.SupportCase) workItem.getParameter("supportCase"), (String) workItem.getParameter("comment"), (String) workItem.getParameter("author"));
        workItemManager.completeWorkItem(workItem.getStringId(), java.util.Collections.singletonMap("supportCase", result));
    }

    public void abortWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
    }

    public String getName() {
        return "org.kie.flexible.kogito.example.service.CommentService_addSupportComment_19_Handler";
    }
}
